==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/store2storetransfer_001/Store2StoreTransfer.java <==

package net.datastream.schemas.mp_entities.store2storetransfer_001;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.STOREID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}FROMSTOREID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TOSTOREID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ADVICENUMBER" minOccurs="0"/>
 *         <element name="PartLines">
 *           <complexType>
 *             <complexContent>
 *               <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 <sequence>
 *                   <element ref="{http://schemas.datastream.net/MP_entities/Store2StoreTransfer_001}PartLine" maxOccurs="unbounded"/>
 *                 </sequence>
 *               </restriction>
 *             </complexContent>
 *           </complexType>
 *         </element>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "description",
    "fromstoreid",
    "tostoreid",
    "advicenumber",
    "partLines"
})
@XmlRootElement(name = "Store2StoreTransfer")
public class Store2StoreTransfer {

    @XmlElement(name = "DESCRIPTION", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String description;
    @XmlElement(name = "FROMSTOREID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STOREID_Type fromstoreid;
    @XmlElement(name = "TOSTOREID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STOREID_Type tostoreid;
    @XmlElement(name = "ADVICENUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String advicenumber;
    @XmlElement(name = "PartLines", required = true)
    protected Store2StoreTransfer.PartLines partLines;

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

    /**
     * Gets the value of the fromstoreid property.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getFROMSTOREID() {
        return fromstoreid;
    }

    /**
     * Sets the value of the fromstoreid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setFROMSTOREID(STOREID_Type value) {
        this.fromstoreid = value;
    }

    /**
     * Gets the value of the tostoreid property.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getTOSTOREID() {
        return tostoreid;
    }

    /**
     * Sets the value of the tostoreid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setTOSTOREID(STOREID_Type value) {
        this.tostoreid = value;
    }

    /**
     * Gets the value of the advicenumber property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getADVICENUMBER() {
        return advicenumber;
    }

    /**
     * Sets the value of the advicenumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setADVICENUMBER(String value) {
        this.advicenumber = value;
    }

    /**
     * Gets the value of the partLines property.
     * 
     * @return
     *     possible object is
     *     {@link Store2StoreTransfer.PartLines }
     *     
     */
    public Store2StoreTransfer.PartLines getPartLines() {
        return partLines;
    }

    /**
     * Sets the value of the partLines property.
     * 
     * @param value
     *     allowed object is
     *     {@link Store2StoreTransfer.PartLines }
     *     
     */
    public void setPartLines(Store2StoreTransfer.PartLines value) {
        this.partLines = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>{@code
     * <complexType>
     *   <complexContent>
     *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       <sequence>
     *         <element ref="{http://schemas.datastream.net/MP_entities/Store2StoreTransfer_001}PartLine" maxOccurs="unbounded"/>
     *       </sequence>
     *     </restriction>
     *   </complexContent>
     * </complexType>
     * }</pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "partLine"
    })
    public static class PartLines {

        @XmlElement(name = "PartLine", required = true)
        protected List<PartLine> partLine;

        /**
         * Gets the value of the partLine property.
         * 
         * <p>
         * This accessor method returns a reference to the live list,
         * not a snapshot. Therefore any modification you make to the
         * returned list will be present inside the Jakarta XML Binding object.
         * This is why there is not a {@code set} method for the partLine property.
         * 
         * <p>
         * For example, to add a new item, do as follows:
         * <pre>
         *    getPartLine().add(newItem);
         * </pre>
         * 
         * 
         * <p>
         * Objects of the following type(s) are allowed in the list
         * {@link PartLine }
         * 
         * 
         * @return
         *     The value of the partLine property.
         */
        public List<PartLine> getPartLine() {
            if (partLine == null) {
                partLine = new ArrayList<>();
            }
            return this.partLine;
        }

    }

}

==> eam-wshub-proxyclient-12.1-3-sources.jar: net/datastream/schemas/mp_entities/store2storetransfer_001/Store2StoreTransfer.java <==

package net.datastream.schemas.mp_entities.store2storetransfer_001;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.STOREID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMSTOREID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOSTOREID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ADVICENUMBER" minOccurs="0"/>
 *         &lt;element name="PartLines">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_entities/Store2StoreTransfer_001}PartLine" maxOccurs="unbounded"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "description",
    "fromstoreid",
    "tostoreid",
    "advicenumber",
    "partLines"
})
@XmlRootElement(name = "Store2StoreTransfer")
public class Store2StoreTransfer {

    @XmlElement(name = "DESCRIPTION", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String description;
    @XmlElement(name = "FROMSTOREID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STOREID_Type fromstoreid;
    @XmlElement(name = "TOSTOREID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STOREID_Type tostoreid;
    @XmlElement(name = "ADVICENUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String advicenumber;
    @XmlElement(name = "PartLines", required = true)
    protected Store2StoreTransfer.PartLines partLines;

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

    /**
     * Gets the value of the fromstoreid property.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getFROMSTOREID() {
        return fromstoreid;
    }

    /**
     * Sets the value of the fromstoreid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setFROMSTOREID(STOREID_Type value) {
        this.fromstoreid = value;
    }

    /**
     * Gets the value of the tostoreid property.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getTOSTOREID() {
        return tostoreid;
    }

    /**
     * Sets the value of the tostoreid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setTOSTOREID(STOREID_Type value) {
        this.tostoreid = value;
    }

    /**
     * Gets the value of the advicenumber property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getADVICENUMBER() {
        return advicenumber;
    }

    /**
     * Sets the value of the advicenumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setADVICENUMBER(String value) {
        this.advicenumber = value;
    }

    /**
     * Gets the value of the partLines property.
     * 
     * @return
     *     possible object is
     *     {@link Store2StoreTransfer.PartLines }
     *     
     */
    public Store2StoreTransfer.PartLines getPartLines() {
        return partLines;
    }

    /**
     * Sets the value of the partLines property.
     * 
     * @param value
     *     allowed object is
     *     {@link Store2StoreTransfer.PartLines }
     *     
     */
    public void setPartLines(Store2StoreTransfer.PartLines value) {
        this.partLines = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_entities/Store2StoreTransfer_001}PartLine" maxOccurs="unbounded"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "partLine"
    })
    public static class PartLines {

        @XmlElement(name = "PartLine", required = true)
        protected List<PartLine> partLine;

        /**
         * Gets the value of the partLine property.
         * 
         * <p>
         * This accessor method returns a reference to the live list,
         * not a snapshot. Therefore any modification you make to the
         * returned list will be present inside the JAXB object.
         * This is why there is not a <CODE>set</CODE> method for the partLine property.
         * 
         * <p>
         * For example, to add a new item, do as follows:
         * <pre>
         *    getPartLine().add(newItem);
         * </pre>
         * 
         * 
         * <p>
         * Objects of the following type(s) are allowed in the list
         * {@link PartLine }
         * 
         * 
         */
        public List<PartLine> getPartLine() {
            if (partLine == null) {
                partLine = new ArrayList<PartLine>();
            }
            return this.partLine;
        }

    }

}
